@@ -69,7 +69,7 @@ class TwistcliIntegration(ABC):
             get_default_post_headers(bc_platform_integration.bc_source, bc_platform_integration.bc_source_version),
             {"Authorization": bc_api_key},
         )
-        url = f"{bc_integration.api_url}{self.vulnerabilities_base_path}/results"
+        url = f"{bc_platform_integration.api_url}{self.vulnerabilities_base_path}/results"
 
         logging.info(f"[twistcli](report_results_async) - reporting results to the server for the file \'{file_path}\'")
         status: int = await aiohttp_client_session_wrapper(url, headers, payload)
