@@ -10,10 +10,6 @@ class GreaterThanAttributeSolver(BaseAttributeSolver):
 
     def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
         vertex_attr = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
-        # if this value contains an underendered variable, then we cannot evaluate the check,
-        # so return True (since we cannot return UNKNOWN)
-        if self._is_variable_dependant(vertex_attr, vertex['source_']):
-            return True
         attr_float = force_float(vertex_attr)
         value_float = force_float(self.value)
 
