@@ -23,15 +23,24 @@ class CustomAttributes:
     ENCRYPTION = "encryption_"
     ENCRYPTION_DETAILS = "encryption_details_"
     TF_RESOURCE_ADDRESS = "__address__"
+    PROVIDER_ADDRESS = "__provider_address__"
     REFERENCES = "references_"
     FOREACH_ATTRS = "foreach_attrs_"
+    SOURCE_MODULE_OBJECT = "source_module_object_"
+    CONNECTED_NODE = "connected_node"
+    VIRTUAL_RESOURCES = "virtual_resources"
 
 
 def props(cls: Any) -> List[str]:
     return [i for i in cls.__dict__.keys() if i[:1] != "_"]
 
 
+def wrap_reserved_attributes(attribute: str, prefix: str = '_') -> str:
+    return f"{prefix}{attribute}"
+
+
 reserved_attribute_names = props(CustomAttributes)
+reserved_attributes_to_scan = [CustomAttributes.RESOURCE_TYPE]
 
 
 class EncryptionValues(str, Enum):
