@@ -1,13 +1,19 @@
 from __future__ import annotations
 
+import logging
+import typing
 from collections.abc import Collection
-from copy import deepcopy
-from typing import Union, Dict, Any, List
+from typing import Union, Dict, Any, List, cast
 
 from checkov.common.graph.graph_builder.graph_components.attribute_names import CustomAttributes
 from checkov.common.graph.graph_builder.utils import calculate_hash, join_trimmed_strings
 from checkov.common.graph.graph_builder.variable_rendering.breadcrumb_metadata import BreadcrumbMetadata
-from checkov.terraform.graph_builder.graph_components.block_types import BlockType
+from checkov.common.util.data_structures_utils import pickle_deepcopy
+
+from bc_jsonpath_ng.ext import parse
+
+if typing.TYPE_CHECKING:
+    from bc_jsonpath_ng import JSONPath
 
 
 class Block:
@@ -26,6 +32,8 @@ class Block:
         "foreach_attrs"
     )
 
+    jsonpath_parsed_statement_cache: "dict[str, JSONPath]" = {}  # noqa: CCE003  # global cache
+
     def __init__(
             self,
             name: str,
@@ -46,7 +54,7 @@ class Block:
             :param attributes: dictionary of the block's original attributes in the origin file
         """
         self.name = name
-        self.config = deepcopy(config)
+        self.config = pickle_deepcopy(config)
         self.path = path
         self.block_type = block_type
         self.attributes = attributes
@@ -63,9 +71,7 @@ class Block:
         for attribute_key, attribute_value in self.attributes.items():
             if has_dynamic_block and attribute_key in dynamic_attributes.keys():  # type: ignore
                 continue
-            if isinstance(attribute_value, dict) or (
-                isinstance(attribute_value, list) and len(attribute_value) > 0 and isinstance(attribute_value[0], dict)
-            ):
+            if self.should_run_get_inner_attributes(attribute_value):
                 inner_attributes = self.get_inner_attributes(
                     attribute_key=attribute_key,
                     attribute_value=attribute_value,
@@ -73,6 +79,10 @@ class Block:
                 attributes_to_add.update(inner_attributes)
         return attributes_to_add
 
+    def should_run_get_inner_attributes(self, attribute_value: Any) -> bool:
+        return isinstance(attribute_value, dict) or (isinstance(attribute_value, list) and len(attribute_value) > 0
+                                                     and isinstance(attribute_value[0], dict))
+
     def __str__(self) -> str:
         return f"{self.block_type}: {self.name}"
 
@@ -85,10 +95,6 @@ class Block:
         base_attributes = self.get_base_attributes()
         self.get_origin_attributes(base_attributes)
 
-        if hasattr(self, "module_dependency") and hasattr(self, "module_dependency_num"):
-            base_attributes[CustomAttributes.MODULE_DEPENDENCY] = self.module_dependency
-            base_attributes[CustomAttributes.MODULE_DEPENDENCY_NUM] = self.module_dependency_num
-
         if self.changed_attributes:
             # add changed attributes only for calculating the hash
             base_attributes["changed_attributes"] = sorted(self.changed_attributes.keys())
@@ -97,22 +103,9 @@ class Block:
             sorted_breadcrumbs = dict(sorted(self.breadcrumbs.items()))
             base_attributes[CustomAttributes.RENDERING_BREADCRUMBS] = sorted_breadcrumbs
 
-        if hasattr(self, 'foreach_attrs'):
-            base_attributes[CustomAttributes.FOREACH_ATTRS] = self.foreach_attrs
-
-        if hasattr(self, 'source_module_object'):
-            base_attributes[CustomAttributes.SOURCE_MODULE_OBJECT] = self.source_module_object
-
         if add_hash:
             base_attributes[CustomAttributes.HASH] = calculate_hash(base_attributes)
 
-        if self.block_type == BlockType.DATA:
-            base_attributes[CustomAttributes.RESOURCE_TYPE] = f'data.{self.id.split(".")[0]}'
-
-        if self.block_type == BlockType.MODULE:
-            # since module names are user defined we are just setting 'module' as resource type for easier searching
-            base_attributes[CustomAttributes.RESOURCE_TYPE] = "module"
-
         if "changed_attributes" in base_attributes:
             # removed changed attributes if it was added previously for calculating hash.
             del base_attributes["changed_attributes"]
@@ -137,7 +130,7 @@ class Block:
 
     def get_hash(self) -> str:
         attributes_dict = self.get_attribute_dict()
-        return attributes_dict.get(CustomAttributes.HASH, "")
+        return cast("str", attributes_dict.get(CustomAttributes.HASH, ""))
 
     def update_attribute(
         self,
@@ -174,7 +167,16 @@ class Block:
             key = join_trimmed_strings(char_to_join=".", str_lst=attribute_key_parts, num_to_trim=i)
             if key.find(".") > -1:
                 additional_changed_attributes = self.extract_additional_changed_attributes(key)
-                self.attributes[key] = attribute_value
+                if key in self.attributes and isinstance(self.attributes[key], dict) and key != attribute_key:
+                    try:
+                        self._update_attribute_based_on_jsonpath_key(attribute_value, key)
+                    except Exception as e:
+                        logging.debug(f"Failed updating attribute for key: {key} and value {attribute_value}."
+                                      f"Falling back to explicitly setting it."
+                                      f"Exception - {e}")
+                        self.attributes[key] = attribute_value
+                else:
+                    self.attributes[key] = attribute_value
                 end_key_part = attribute_key_parts[len(attribute_key_parts) - 1 - i]
                 if transform_step and end_key_part in ("1", "2"):
                     # if condition logic during the transform step breaks the values
@@ -186,6 +188,39 @@ class Block:
                         for changed_attribute in additional_changed_attributes:
                             self.changed_attributes[changed_attribute] = previous_breadcrumbs
 
+    def _update_attribute_based_on_jsonpath_key(self, attribute_value: Any, key: str) -> None:
+        """
+        When updating all the attributes we might try to update a specific attribute inside a complex object,
+        so we use jsonpath to refer to the specific location only.
+        """
+        if key not in Block.jsonpath_parsed_statement_cache:
+            jsonpath_key = self._get_jsonpath_key(key)
+            expr = parse(jsonpath_key)
+            Block.jsonpath_parsed_statement_cache[key] = expr
+        else:
+            expr = Block.jsonpath_parsed_statement_cache[key]
+        match = expr.find(self.attributes)
+        if match:
+            match[0].value = attribute_value
+        return None
+
+    @staticmethod
+    def _get_jsonpath_key(key: str) -> str:
+        jsonpath_key = "$."
+        key_parts = key.split(".")
+        updated_parts = []
+        for part in key_parts:
+            if part.isnumeric():
+                updated_parts.append(f"[{part}]")
+            elif "/" in part or "::" in part:
+                updated_parts.append(f'"{part}"')
+            else:
+                updated_parts.append(part)
+        jsonpath_key += ".".join(updated_parts)
+        # Replace .0 with [0] to match jsonpath style
+        jsonpath_key = jsonpath_key.replace(".[", "[")
+        return jsonpath_key
+
     def update_inner_attribute(
         self, attribute_key: str, nested_attributes: list[Any] | dict[str, Any], value_to_update: Any
     ) -> None:
@@ -244,7 +279,7 @@ class Block:
     def get_export_data(self) -> Dict[str, Union[bool, str]]:
         return {"type": self.block_type, "name": self.name, "path": self.path}
 
-    def get_base_attributes(self) -> Dict[str, Union[str, List[str], Dict[str, Any]]]:
+    def get_base_attributes(self) -> Dict[str, Any]:
         return {
             CustomAttributes.BLOCK_NAME: self.name,
             CustomAttributes.BLOCK_TYPE: self.block_type,
