@@ -3,10 +3,10 @@ from __future__ import annotations
 import logging
 from collections.abc import Sequence
 from json import JSONDecoder
-from json.decoder import WHITESPACE, WHITESPACE_STR, BACKSLASH, STRINGCHUNK, JSONArray  # type:ignore[attr-defined]  # they are not explicitly exported
+from json.decoder import WHITESPACE, WHITESPACE_STR, BACKSLASH, STRINGCHUNK, JSONArray  # type:ignore  # they are not explicitly exported
 from typing import Any, Callable, Pattern, Match
 
-from json.scanner import NUMBER_RE  # type:ignore[import]  # is not explicitly exported
+from json.scanner import NUMBER_RE  # type:ignore  # is not explicitly exported
 
 from checkov.common.parsers.node import StrNode, DictNode, ListNode
 from checkov.common.parsers.json.errors import NullError, DuplicateError, DecodeError
@@ -392,7 +392,7 @@ class Decoder(JSONDecoder):
         """
             Check for duplicate keys on the current level, this is not desirable
             because a dict does not support this. It overwrites it with the last
-            occurance, which can give unexpected results
+            occurrence, which can give unexpected results
         """
         mapping = DictNode({}, beg_mark, end_mark)
         for key, value in ordered_pairs:
