@@ -1,4 +1,4 @@
-from checkov.common.models.enums import CheckResult, CheckCategories
+from checkov.common.models.enums import CheckCategories
 from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
 
 
@@ -10,7 +10,6 @@ class PostgresSQLTreatDetectionEnabled(BaseResourceValueCheck):
         categories = [CheckCategories.GENERAL_SECURITY]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
-
     def get_inspected_key(self):
         return "threat_detection_policy/[0]/enabled"
 
