@@ -1,13 +1,20 @@
+from __future__ import annotations
+
 import itertools
 import logging
+import os
 import re
 from datetime import datetime, timedelta
 from functools import reduce
 from math import ceil, floor, log
 from typing import Union, Any, Dict, Callable, List, Optional
+from asteval import Interpreter
 
 from checkov.terraform.parser_functions import tonumber, FUNCTION_FAILED, create_map, tobool, tostring
 
+TIME_DELTA_PATTERN = re.compile(r"(\d*\.*\d+)")
+RANGE_PATTERN = re.compile(r'^\d+-\d+$')
+
 """
 This file contains a custom implementation of the builtin `eval` function.
 `eval` is not a safe function, because it can execute *every* command,
@@ -139,7 +146,7 @@ def timeadd(input_str: str, time_delta: str) -> str:
         adding = False
         time_delta = time_delta[1:]
     # Split out into each of the deltas
-    deltas = re.split(r'(\d*\.*\d+)', time_delta)
+    deltas = re.split(TIME_DELTA_PATTERN, time_delta)
     # Needed to strip the leading empty element
     deltas = list(filter(None, deltas))
     while len(deltas) > 0:
@@ -255,9 +262,29 @@ def formatdate(format_str: str, input_str: str) -> str:
     return dt.strftime(processed_format_str)
 
 
+def terraform_try(*args: Any) -> Any:
+    """
+    From terraform docs:
+        "try evaluates all of its argument expressions in turn and returns the result of the first one that does not
+        produce any errors."
+    """
+    for arg in args:
+        try:
+            return evaluate(arg) if isinstance(arg, str) else arg
+        except Exception as e:
+            logging.warning(f"Error in evaluate_try of argument {arg} - {e}")
+            continue
+    raise Exception(f"No argument can be evaluated for try of {args}")
+
+
 SAFE_EVAL_FUNCTIONS: List[str] = []
 SAFE_EVAL_DICT = dict([(k, locals().get(k, None)) for k in SAFE_EVAL_FUNCTIONS])
 
+
+# type conversion functions
+TRY_STR_REPLACEMENT = "__terraform_try__"
+SAFE_EVAL_DICT[TRY_STR_REPLACEMENT] = terraform_try
+
 # math functions
 SAFE_EVAL_DICT["abs"] = abs
 SAFE_EVAL_DICT["ceil"] = ceil
@@ -293,7 +320,7 @@ SAFE_EVAL_DICT["upper"] = lambda input_str: input_str.upper()
 SAFE_EVAL_DICT["chunklist"] = lambda lst, chunk_size: [lst[i : i + chunk_size] for i in range(0, len(lst), chunk_size)]
 SAFE_EVAL_DICT["coalesce"] = coalesce
 SAFE_EVAL_DICT["coalescelist"] = coalesce_list
-SAFE_EVAL_DICT["compact"] = lambda lst: list(filter(lambda l: l != "", lst))
+SAFE_EVAL_DICT["compact"] = lambda lst: list(filter(lambda value: value != "", lst))
 SAFE_EVAL_DICT["concat"] = lambda *lists: list(itertools.chain(*lists))
 SAFE_EVAL_DICT["contains"] = lambda lst, value: value in lst
 SAFE_EVAL_DICT["distinct"] = lambda lst: list(dict.fromkeys(lst))
@@ -310,6 +337,7 @@ SAFE_EVAL_DICT["merge"] = merge
 # SAFE_EVAL_DICT['range']
 SAFE_EVAL_DICT["reverse"] = reverse
 SAFE_EVAL_DICT["sort"] = sort
+SAFE_EVAL_DICT["zipmap"] = lambda *lists: dict(zip(*lists))  # noqa: B905
 
 
 # type conversion
@@ -329,14 +357,42 @@ SAFE_EVAL_DICT["timeadd"] = timeadd
 SAFE_EVAL_DICT["formatdate"] = formatdate
 
 
+def get_asteval() -> Interpreter:
+    # asteval provides a safer environment for evaluating expressions by restricting the operations to a secure subset, significantly reducing the risk of executing malicious code.
+    return Interpreter(
+        symtable=SAFE_EVAL_DICT,
+        use_numpy=False,
+        minimal=True
+    )
+
+
 def evaluate(input_str: str) -> Any:
-    if "__" in input_str:
-        logging.debug(f"got a substring with double underscore, which is not allowed. origin string: {input_str}")
-        return input_str
-    if input_str == "...":
+    """
+    Safely evaluate a Terraform-like function expression using a predefined function map.
+    Falls back gracefully if evaluation fails.
+    """
+    if not input_str or input_str == "...":
         # don't create an Ellipsis object
         return input_str
-    evaluated = eval(input_str, {"__builtins__": None}, SAFE_EVAL_DICT)  # nosec
+    if input_str.startswith("try"):
+        # As `try` is a saved word in python, we can't override it like other functions as `eval` won't accept it.
+        # Instead, we are manually replacing this string with our own custom string, so we can pass it to `eval`.
+
+        # Don't use str.replace to make sure we replace just the first occurrence
+        input_str = f"{TRY_STR_REPLACEMENT}{input_str[3:]}"
+    asteval = get_asteval()
+    log_level = os.getenv("LOG_LEVEL")
+    should_log_asteval_errors = log_level == "DEBUG"
+    if RANGE_PATTERN.match(input_str):
+        temp_eval = asteval(input_str, show_errors=should_log_asteval_errors)
+        evaluated = input_str if temp_eval < 0 else temp_eval
+    else:
+        evaluated = asteval(input_str, show_errors=should_log_asteval_errors)
+
+    if asteval.error:
+        error_messages = [err.get_error() for err in asteval.error]
+        raise ValueError(f"Safe evaluation error: {error_messages}")
+
     return evaluated if not isinstance(evaluated, str) else remove_unicode_null(evaluated)
 
 
