@@ -1,15 +1,21 @@
+from __future__ import annotations
+
 import os
 import re
 from dataclasses import dataclass
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 from checkov.common.goget.github.get_git import GitGetter
 from checkov.terraform.module_loading.content import ModuleContent
 
 from checkov.terraform.module_loading.loader import ModuleLoader
-from checkov.terraform.module_loading.module_params import ModuleParams
+
+if TYPE_CHECKING:
+    from checkov.terraform.module_loading.module_params import ModuleParams
 
 DEFAULT_MODULE_SOURCE_PREFIX = "git::https://"
+GIT_USER_PATTERN = re.compile(r"^(.*?@).*")
 
 
 @dataclass(frozen=True)
@@ -22,19 +28,19 @@ class ModuleSource:
 
 
 class GenericGitLoader(ModuleLoader):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.module_source_prefix = DEFAULT_MODULE_SOURCE_PREFIX
 
     @property
-    def module_source_prefix(self):
+    def module_source_prefix(self) -> str:
         return self._module_source_prefix
 
     @module_source_prefix.setter
-    def module_source_prefix(self, prefix):
+    def module_source_prefix(self, prefix: str) -> None:
         self._module_source_prefix = prefix
 
-    def discover(self, module_params: ModuleParams):
+    def discover(self, module_params: ModuleParams) -> None:
         module_params.vcs_base_url = os.getenv("VCS_BASE_URL", "")  # format - https://example.com
         module_params.module_source_prefix = f"git::{module_params.vcs_base_url}" if module_params.vcs_base_url else None
         module_params.username = os.getenv("VCS_USERNAME", None)
@@ -55,7 +61,6 @@ class GenericGitLoader(ModuleLoader):
     def _load_module(self, module_params: ModuleParams) -> ModuleContent:
         try:
             self._process_generic_git_repo(module_params)
-
             module_source = module_params.module_source.replace("git::", "")
             git_getter = GitGetter(module_source, create_clone_and_result_dirs=False)
             git_getter.temp_dir = module_params.dest_dir
@@ -67,9 +72,10 @@ class GenericGitLoader(ModuleLoader):
                 # but the current loader (ex. GithubLoader) is not using it
                 return ModuleContent(dir=None, failed_url=module_params.module_source)
             if 'File exists' not in str_e and 'already exists and is not an empty directory' not in str_e:
-                self.logger.warning(f"failed to get {module_params.module_source} because of {e}")
+                self.logger.warning(f"failed to get {module_params.module_source} in git loader because of {e}")
                 return ModuleContent(dir=None, failed_url=module_params.module_source)
         return_dir = module_params.dest_dir
+        self.logger.info(f'finished loading {module_params.module_source}')
         if module_params.inner_module:
             return_dir = os.path.join(module_params.dest_dir, module_params.inner_module)
         return ModuleContent(dir=return_dir)
@@ -107,9 +113,11 @@ class GenericGitLoader(ModuleLoader):
         else:
             raise Exception("invalid git url")
 
-        username = re.match(re.compile(r"^(.*?@).*"), root_module)
-        if username and username[1] != "git@":
-            root_module = root_module.replace(username[1], "")
+        username = None
+        if "@" in root_module:
+            username = re.match(GIT_USER_PATTERN, root_module)
+            if username and username[1] != "git@":
+                root_module = root_module.replace(username[1], "")
 
         if root_module.endswith(".git"):
             root_module = root_module[:-4]
