@@ -1,9 +1,15 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from checkov.terraform.module_loading.loaders.git_loader import GenericGitLoader
-from checkov.terraform.module_loading.module_params import ModuleParams
+
+if TYPE_CHECKING:
+    from checkov.terraform.module_loading.module_params import ModuleParams
 
 
 class GithubLoader(GenericGitLoader):
-    def discover(self, module_params: ModuleParams):
+    def discover(self, module_params: ModuleParams) -> None:
         self.module_source_prefix = "github.com"
 
     def _is_matching_loader(self, module_params: ModuleParams) -> bool:
